@@ -5,13 +5,13 @@ and array types to provides a slightly different interface. The interface tries
 to be the same as the  `CleverSheep.Test.Struct` module, which this module
 effectively replaces.
 
-This is not intended to ba any sort of replacement for ``ctypes`` just a
+This is not intended to be any sort of replacement for ``ctypes`` just a
 different way of using part of it. You may well often be better off using the
 ``ctypes`` module directly.
 
 This is intended to be a replacement what for the `CleverSheep.Test.Struct`
 module. The old Struct module is effectively unmaintained and this should be
-considered first choice whever possible.
+considered first choice wherever possible.
 
 This depends on the availability of ``ctypes``, which is part of the C-Python
 standard library from version 2.5 and available separately for Python 2.4. It
@@ -32,8 +32,8 @@ try:
     import ctypes
 except ImportError: #pragma: unreachable
     raise ImportError(
- """CStruct module requires the ctypes module. For pre-Python2.5 you can
- obtain the ctypes module from http://python.net/crew/theller/ctypes/""")
+        """CStruct module requires the ctypes module."""
+    )
 
 
 _string_types = {
@@ -43,6 +43,7 @@ _string_types = {
 
 class _Member(object):
     _seq = 0
+
     def __init__(self, cType):
         self.seq = _Member._seq
         self.cType = cType
@@ -129,6 +130,7 @@ if 1:
             ctype_to_stdtint[t] = t
         ctype_to_stdtint[t] = t
 
+
 class _Type(object):
     """See the later defined Type variable for details."""
     definedTypes = {}
@@ -201,6 +203,7 @@ _ctypeMap = {
     ("union", Format.LittleEndian): ctypes.Union,
 }
 
+
 class MetaStructType(MetaCompoundType):
     def __new__(cls, name, bases, d):
         klass = super(MetaStructType, cls).__new__(cls, name, bases, d,
@@ -248,9 +251,9 @@ def Struct__init__(self, _rawData=None, trim=False, **kwargs):
         setattr(self, name, value)
 
 
-# TODO: This only exist to raise AttributeError when we try to assign
-#       to a non-existant attribute. For some reason, ctypes lets us do
-#       just that without any error.
+# This only exist to raise AttributeError when we try to assign
+# to a non-existent attribute. For some reason, ctypes lets us do
+# just that without any error.
 def Struct__setattr__(self, name, value):
     if not hasattr(self, name):
         raise AttributeError(name)
