@@ -15,8 +15,6 @@ import stat
 import re
 import fnmatch
 
-from CleverSheep.Prog.Aspects import decorator
-
 # TODO: This breaks if no .PROJECT_ROOT exists.
 
 #: The projectRoot is used to determine the relative path of file names. This
@@ -134,29 +132,26 @@ def rmFile(path, parentDir=None):
         os.unlink(path)
 
 
-# TODO: I am not happy with this. It probably should **really** check that the
-#       directory is empty. It was added to support Mym's cache.
 def rmEmptyDir(path):
     """Remove the directory `path` if it is empty.
 
     This will try to remove a directory, failing silently if the directory
     is not empty.
 
-    Actually this is a bit of a cheat. All it really does is try to remove the
-    directory and suppress error conditions. Thus, failure could be for a
-    reason other than the directory not being empty.
-
     :Return:
         True if the directory was removed, a false value otherwise.
     :Param path:
         The path of the directory to be removed.
-
     """
-    try:
-        os.rmdir(path)
-    except OSError as exc:
-        return False
-    return True
+    if os.path.exists(path) and os.path.isdir(path):
+        if not os.listdir(path):
+            try:
+                os.rmdir(path)
+                return True
+            except OSError:
+                pass
+
+    return False
 
 
 def relName(path, cwd=None, root=None):
@@ -204,7 +199,6 @@ def relName(path, cwd=None, root=None):
     return path
 
 
-# TODO: Should probably move to Utils.
 def normPath(path, parentDir):
     """Return a normalised absolute path for path.
 
@@ -285,7 +279,6 @@ class Stat(object):
         """Do not use!
 
         """
-        # TODO: Find a better name
         return self.relName(cwd=projectRoot)
 
     def mode(self):
@@ -354,7 +347,6 @@ class Stat(object):
         """
         return os.path.getsize(self.path)
 
-    # TODO: We could optimize by caching some of the following.
     def ext(self):
         """Returns the extension (including dot) of the name."""
         return os.path.splitext(self.path)[1]
@@ -383,7 +375,7 @@ class Stat(object):
 
         """
         rel = self.relName(dirPath)
-        if rel[0] not in "."+ os.sep:  # TODO: Not portable
+        if rel[0] not in "." + os.sep:  # TODO: Not portable
             return True
 
     def isInDir(self, dirPath): #pragma: unsupported
@@ -391,7 +383,6 @@ class Stat(object):
         return self.dir() != os.path.abspath(dirPath)
 
 
-
 class File(Stat):
     """Uses the `Stat` mixin to provide abstract access to a file.
 
