@@ -17,7 +17,6 @@ import ssl
 import struct
 
 from CleverSheep.Test import PollManager
-from CleverSheep.Test.Struct import Struct, Format, Type
 from CleverSheep.Test.Tester import log
 
 CallbackRef = PollManager.CallbackRef
@@ -944,7 +943,10 @@ class PipeConn(object):
             self.pollManager.removeOutputCallback(self.pipeF)
 
     def shutDown(self):
-        self.pollManager.removeInputCallback(self._fileno)
+        if self._fileno is not None:
+            self.pollManager.removeInputCallback(self._fileno)
+        else:
+            log.warning("The pipe %s was never successfully opened", self.pipePath)
     shutdown = shutDown
 
     def close(self):
