@@ -12,7 +12,7 @@ import inspect
 import os
 import sys
 
-from CleverSheep.Extras.decorator import decorator
+from decorator import decorator
 from CleverSheep.Prog import Files
 from CleverSheep.Sys import Platform
 from CleverSheep.Test import ImpUtils
@@ -471,7 +471,7 @@ def collectFromNamespace(collection, instance, info, parent):
       collection
         The collection of all tests and suites.
       instance
-        The TODO
+        Unused
       info
         TODO
       parent
@@ -482,7 +482,6 @@ def collectFromNamespace(collection, instance, info, parent):
 
     # First find any 'bare' tests within the namespace and and add each to the
     # collection, as a `Test` instance, in sorted order.
-    # TODO: Change _getTestKey to avoid two loops.
     context = Context.getContext(dirPath=os.getcwd())
     tests = []
     for name, value in info.items():
@@ -561,7 +560,9 @@ def _getSuiteKey(v):
 def _getTestKey(v):
     name, func = v
     if hasattr(func, "cs_test_info"):
-        return 0, func.cs_test_info._test_seq
+        if func.cs_test_info._test_seq is not None:
+            return 0, func.cs_test_info._test_seq
+        return 1, -1
     return 1, name
 
 
@@ -572,13 +573,7 @@ class Hints(object):
 
 # TODO: Both testspec.py and Collection.py use inspect for source code.
 #       Would be nice to avoid doing the same thing twice.
-def _getSource(obj, hints=None):
-    source =  klass = name = None
-
-    # Use any available hints in preference.
-    if hints:
-        klass = hints.klass
-
+def _getSource(obj):
     # For instance methods we want the source of the bound class.
     cls = getattr(obj, "__class__", None)
     if cls is not None:
@@ -623,8 +618,8 @@ def _getSource(obj, hints=None):
 def getSig(obj, hints=None):
     from CleverSheep.Test import Tester
 
-    source = klass = name = None
-    source = _getSource(obj, hints)
+    klass = name = None
+    source = _getSource(obj)
     sourceDir = os.path.dirname(os.path.abspath(source))
     if Tester.treeRoot is not None:
         relName = Files.relName(os.path.abspath(source), Tester.treeRoot)
