@@ -472,23 +472,6 @@ class TestItem(object):
         """
         return self._collection.getAncestors(self)
 
-    def hasFailingAncestor(self):
-        """Check if any ancestor is considered to have failed.
-
-        An ancestor suite has failed if, for example, its ``suiteSetup``
-        failed.
-
-        :Return:
-            ``True`` if any ancestors has failed.
-
-        """
-        parent = self.parent
-        if parent is None:
-            return
-        # TODO: Temporarily disabled.
-        return
-        return parent.hasFailed or parent.hasFailingAncestor()
-
     def _getNamespace(self, namespace=None):
         return namespace or dict([(n, getattr(self.item, n))
             for n in dir(self.item)])
@@ -592,6 +575,20 @@ class TestItem(object):
         if f:
             return os.path.dirname(f)
 
+    @property
+    def execPath(self):
+        p = self.namespace.get("_exec_path_", None)
+        if p is None and self.parent is not None:
+                p = self.parent.execPath
+
+        return p
+
+    @property
+    def execDir(self):
+        f = self.execPath
+        if f:
+            return os.path.dirname(f)
+
     @property
     def isBug(self):
         return False
