@@ -11,7 +11,6 @@ from CleverSheep.Test.Tester import Coordinator
 from CleverSheep.Test.Tester import Errors
 
 from CleverSheep.Test.Tester import Logging
-from CleverSheep.Test.Tester import WatchDog
 from CleverSheep.Test.Tester import CmdLine
 from CleverSheep.Test.Tester import options
 from CleverSheep.App import Config
@@ -157,11 +156,6 @@ class ParserManager(object):
             help="Set the logging level to LEVEL (default = debug)."
                  " Valid values: %s" % " ".join(
                 Logging.validLevels))
-        self.main_argument_parser.add_argument(
-            "--timeout", action="store",
-            type=int,
-            metavar="T", default=0,
-            help="Do not use this - its behaviour is not well defined.")
         self.main_argument_parser.add_argument(
             "--uids", action="append",
             default=[],
@@ -430,11 +424,6 @@ def parseCoreOptions(features={}):
     logger.setLogLevel(getattr(logging, log_level.upper()))
 
 
-def processOptions():
-    if options.get_option_value("timeout"):
-        setDefaultTimeout(options.get_option_value("timeout"))
-
-
 def parseCommandLineOptions(features={}):
     # Parse command line. First pass is with the Tester's built-in options
     # and then a second pass looks for user-defined options.
@@ -445,7 +434,6 @@ def parseCommandLineOptions(features={}):
     if rcpath:
         options.set_config_file_options(rcpath, values)
 
-    processOptions()
     parseUserOptions()
 
     # Allow test scripts the chance to react to the end of command line
@@ -546,23 +534,6 @@ def currentTestHasFailed():
     return manager.executingTest.hasFailed
 
 
-def setDefaultTimeout(timeoutPeriod):
-    """Set the default watchdog timeout period.
-
-    Tests can be run with a watchdog active to force tests to terminate after
-    a specific time. This is useful, for example, in unattended overnight test runs
-    where you wish to ensure that a non-terminating test run is treated as an error,
-    so that subsequent test runs get a chance to execute.
-
-    Normally the default timeout is ``None``; i.e. disabled.
-
-    :Param timeoutPeriod:
-        The watchdog timeout period in whole seconds.
-    """
-
-    options.set_option("timeout", timeoutPeriod)
-
-
 #}
 #{ Test script entry points
 
@@ -580,30 +551,25 @@ def currentTestInfo():
         return test.info
 
 
-class General(object):
-    """Base class for the General service.
+class CSGeneral(Coordinator.Provider):
+    """A general to command the test troops.
 
     """
     features = {
 
     }
 
+    def __init__(self):
+        pass
+
     def collectTests(self, collectMethod, info, ignoreFiles=[]):
         # Find a collector
         collector = Coordinator.getServiceProvider("collection")
         collect_func = collector.getFunction(collectMethod)
 
         # TODO: Collection should possibly interact with the manager.
-        try:
-            sys.stdout.flush()
-            collection = WatchDog.runUnderWatchDog(
-                options.get_option_value("timeout"),
-                collector.doCollect, collect_func, info,
-                ignoreFiles=ignoreFiles)
-        except WatchDog.Timeout as exc:
-            sys.stderr.write("Timout during test collection\n")
-            sys.stderr.write(Errors.fmtException(exc) + "\n")
-            sys.exit(1)
+        sys.stdout.flush()
+        collection = collector.doCollect(collect_func, info, ignoreFiles=ignoreFiles)
 
         fail = False
         collection.prune()
@@ -617,18 +583,6 @@ class General(object):
         invokePostCollectionCallbacks(collection)
         return collection
 
-
-class CSGeneral(Coordinator.Provider, General):
-    """A general to command the test troops.
-
-    """
-    features = {
-
-    }
-
-    def __init__(self):
-        pass
-
     def bootStrap(self, collectMethod, info):
         """Run the test framework.
 
