@@ -831,6 +831,13 @@ class Screen(FileLikeReporter):
             spec = test.getTestProcedure()
             # TODO: Code largely duplicated in sphinx.py.
             prefixLens = [0] * 30
+            # Pre-populate the array with values starting at 0, then 3 then going up in steps of 2.
+            # We do this as we're looping over the #> comments which might be skipped in some functions but we don't
+            # want gaps in the array
+            for i in range(1, 30):
+                prefixLens[i] = (i-1) * 2 + 3
+
+            # Not sure this is actually needed but left in anyway as it shouldn't do any harm
             for n, block, boundArgs in spec.walkSteps():
                 num = ".".join("%d" % v for v in n) + ". "
                 idx = len(n)
@@ -847,7 +854,7 @@ class Screen(FileLikeReporter):
                 sNormal.write("\n")
 
                 num = ".".join("%d" % v for v in n) + ". "
-                hangStr = "%*s%-*s" % (a, "", b, num)
+                hangStr = "%*s%s" % (a, "", num)
                 for line in addHang(block, hangStr):
                     sNormal.write("%s      %s\n" % (ind, line))
                 didSteps = True
