@@ -6,16 +6,18 @@ import weakref
 
 from CleverSheep.Test.Tester import Coordinator
 from CleverSheep.Test.Tester import log
+from CleverSheep.Test.Tester import options
 
 rProcCall = re.compile(r' *(?P<name>[a-zA-Z0-9_.]+)\(')
 rFuncCall = re.compile(r'[^=]*= *(?P<name>[a-zA-Z0-9_.]+)\(')
 rStepComment = re.compile(r'^ *# ?> (.*)')
 rComment = re.compile(r'^ *#(.*)')
 
+
 def getFuncClassID(func):
     this = getattr(func, "__self__", None)
     if this is None:
-        funcClass = getattr(this, "__class__", None)
+        funcClass = getattr(func, "im_class", None)
     else:
         funcClass = getattr(this, "__class__", None)
     if funcClass is None:
@@ -30,10 +32,8 @@ class TestSpecDB(object):
         self._stepMap = {}
 
     def gatherTestSteps(self, func):
-        _, classID = getFuncClassID(func)
         f = TestMap.getTestMap(func)
         if f is not None:
-            #self.dump(f)
             self.getMap(f)
 
     def getThing(self, func):
@@ -118,7 +118,6 @@ class Step(PointOfInterest):
         return "\n".join(self.lines)
 
 
-
 class BoundStep(Step):
     def __init__(self, funcPoint, stepPoint):
         super(BoundStep, self).__init__(stepPoint.lNum, stepPoint.lines)
@@ -135,6 +134,7 @@ def unwrapFunc(func):
         func = func.undecorated
     return func
 
+
 tpl = '''class _X_(object):
     def %s(self, *args, **kwargs):
         self.args = args
@@ -150,6 +150,7 @@ inst.go()
 
 propagateArgErrs = True
 
+
 def bindArgsForInvocation(calledFunc, callCode, namespace=None):
     calledName = calledFunc.func.__name__
     callCode = callCode.strip()
@@ -192,6 +193,7 @@ class TestMap(PointOfInterest):
     sortV = 100
     type = "func"
     _known = {}
+    _classMap = {}
 
     def __init__(self, func, cls):
         linecache.checkcache()
@@ -201,7 +203,7 @@ class TestMap(PointOfInterest):
         try:
             func = unwrapFunc(func)
             self.lines, self.startLine = inspect.getsourcelines(func)
-        except: # Exception types difficult to predict
+        except:  # Exception types difficult to predict
             self.startLine = 0
             self.lines = []
         self.invocations = []
@@ -239,6 +241,10 @@ class TestMap(PointOfInterest):
             if calledFunc is None:
                 return True
 
+            try:
+                self._classMap[calledFunc] = cls
+            except TypeError:
+                pass
             if not (isMethodOrFunc(calledFunc)
                     or hasattr(calledFunc, "_cs_isProcedural")):
                 return True
@@ -266,6 +272,9 @@ class TestMap(PointOfInterest):
 
         step = []
         module = inspect.getmodule(self.func)
+        klass = self.cls
+        if klass is None:
+            klass = self._classMap.get(self.func, None)
         for lineIdx, line in enumerate(self.lines):
             m = rStepComment.match(line)
             if m:
@@ -275,7 +284,7 @@ class TestMap(PointOfInterest):
             if rComment.match(line):
                 continue
 
-            if self.processInvocation(lineIdx, line, emitStep, module, self.cls):
+            if self.processInvocation(lineIdx, line, emitStep, module, klass):
                 continue
 
             if line.strip():
@@ -317,27 +326,32 @@ class TestMap(PointOfInterest):
             if p.type == "step":
                 while len(n) > level + 1:
                     n.pop()
-                while len(n) <= level:
-                    n.append(0)
-                n[-1] += 1
-                pad = "  " * level
+                if len(n) <= level:
+                    while len(n) <= level:
+                        n.append(1)
+                else:
+                    n[-1] += 1
+
                 yield n, p.lines, boundArgs
 
     @classmethod
-    def getTestMap(cls, func, funcClass=None):
-        if not hasattr(func, "__code__"):
-            return
+    def getTestMap(cls, func):
 
-        if funcClass is not None:
-            funcClassID = id(funcClass)
+        if options.get_option_value("details"):
+            # If we cache the map values we don't get the correct output when the --details arg is used, however not
+            # caching them is a fairly large performance hit so we only do it specifically for the details
+            funcClass, _ = getFuncClassID(func)
+            funcMap = TestMap(func, funcClass)
+            funcMap.getStepsAndCalls()
+            return funcMap
         else:
             funcClass, funcClassID = getFuncClassID(func)
-        key = func.__code__, funcClassID
-        if key not in cls._known:
-            funcMap = TestMap(func, funcClass)
-            cls._known[key] = funcMap
-            funcMap.getStepsAndCalls()
-        return cls._known[key]
+            key = func.__code__, funcClassID
+            if key not in cls._known:
+                funcMap = TestMap(func, funcClass)
+                cls._known[key] = funcMap
+                funcMap.getStepsAndCalls()
+            return cls._known[key]
 
 
 class RunTracer(object):
@@ -354,6 +368,15 @@ class RunTracer(object):
         self._stepMap = stepMap
         self._prevKey = None
 
+        # A cache map of step index sequences mapping a tuple sequence of index
+        # values to the latest value used at the next nested level of that
+        # test step index sequence. The tuple (0,) is special meaning the root
+        # top level index.
+        # e.g. {(1,2,): 5} means that the most recent nested test index used
+        # after 1.2 is 5, giving a test index 1.2.5 to start from and increment
+        # for the next test step at that level.
+        self.stepIdxMap = {(0,): 0}
+
     def run(self, func, args, kwargs):
         self.oldTrace = sys.gettrace()
         self.lineTrace = None
@@ -379,10 +402,29 @@ class RunTracer(object):
         callPoint = self._callMap.get(code, None)
         if callPoint is not None:
             if callPoint.levelAdjust == 0:
+                # Save the current state of the test step index values
                 nToSave = list(self.n)
-                self.n.append(0)
+
+                if not self.n or len(self.n) == 1:
+                    # Dealing with the top level (root) test step, ensure
+                    # it is set to the latest value in the index cache
+                    self.n = [self.stepIdxMap.get((0,), 0)]
+
+                # Note this code doesn't produce the same output as --details would in terms of test numbering
+                # Instead of say 1.1.1.1 where the second and 3rd level have no calls you get 1.1
+                # Trying to correctly fix this while also keeping the cs_inline working has proved too difficult so
+                # for now I have just left it how Fractal had it as no one else would care
+                if callPoint.steps and self.n[-1] != 0:
+                    # The function about to be called contains test steps
+                    # and the deepest nested step index is not zero
+                    # which means a new level of step index should be added.
+                    # Use the index cache to get the latest value for this
+                    # new level if it has already been reached, or start at 0.
+                    stepKey = tuple(self.n)
+                    self.n.append(self.stepIdxMap.get(stepKey, 0))
             else:
                 nToSave = self.n
+
             self.stack.append((self.code, nToSave, self.lineTrace))
             self.lineTrace = lineTrace
             self.code = code
@@ -391,7 +433,7 @@ class RunTracer(object):
 
     def handleLine(self, frame, event, arg):
         if self.lineTrace:
-            ret = self.lineTrace(frame, event, arg)
+            _ = self.lineTrace(frame, event, arg)
         stepKey = self.code, frame.f_lineno
         stepPoint = self._stepMap.get(stepKey, None)
         if stepPoint is not None:
@@ -399,15 +441,44 @@ class RunTracer(object):
                 return
             self._prevKey = stepKey
             self.n[-1] += 1
-            ind = "  " * (len(self.stack) - 1)
+
             nStr = ".".join(str(v) for v in self.n) + "."
             self.update_commentary([nStr] + stepPoint.lines)
+
+            # Record the latest step index that has just been used at
+            # this nested level
+            if len(self.n) > 1:
+                indexKey = tuple(self.n[:-1])
+            else:
+                indexKey = (0,)
+            self.stepIdxMap[indexKey] = self.n[-1]
             return self.trace
 
     def handleReturn(self, frame, event, arg):
         if self.lineTrace:
             self.lineTrace(frame, event, arg)
+        # record the current state of the test step index values before
+        # restoring to the calling functions version.
+        if self.n:
+            currentStepNumbers = list(self.n)
+        else:
+            currentStepNumbers = None
+
         self.code, self.n, self.lineTrace = self.stack.pop()
+
+        if self.n and currentStepNumbers:
+            # It is possible that test steps at this level have
+            # updated nested step level values shared by the calling function
+            # It is important to update the restored step index values
+            # to match these values in case there are any test steps
+            # in the calling function that follow the call we are just
+            # returning from.
+            checkLength = min(len(self.n), len(currentStepNumbers))
+
+            for index in range(checkLength):
+                if self.n[index] < currentStepNumbers[index]:
+                    self.n[index] = currentStepNumbers[index]
+
         return self.trace
 
     def update_commentary(self, lines):
