@@ -19,7 +19,7 @@ try:
 except ImportError:
     pass
 except AttributeError: #pragma: debug
-    pass # For epydoc processing
+    pass  # For epydoc processing
 
 
 streams = {}
@@ -336,9 +336,7 @@ class Commentary(object):
 
 
 class _Struct(object):
-    """General structure to hold a collection of values.
-
-    """
+    """General structure to hold a collection of values."""
 
 
 class SequenceChart(object):
@@ -392,7 +390,7 @@ class SequenceChart(object):
     def partyEmphasis(self, name):
         return self._partyEmphasis.get(name, None)
 
-    def setParties (self, parties):
+    def setParties(self, parties):
         """Define the parties for the chart.
 
         Used to set/modify the parties exchanging message, post construction.
@@ -841,4 +839,3 @@ class DumpStream(object):
                 fg = bg = bold = None
             self.f.write("%r\n" % {
                 "bg": bg, "fg": fg, "bold": bold, "text": arg,})
-
